/*
 * Copyright (c) 2008, 2009, 2010, 2011, 2012, 2013
 *   Jonathan Schleifer <js@webkeks.org>
 *
 * All rights reserved.
 *
 * This file is part of ObjFW. It may be distributed under the terms of the
 * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
 * the packaging of this file.
 *
 * Alternatively, it may be distributed under the terms of the GNU General
 * Public License, either version 2 or 3, which can be found in the file
 * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
 * file.
 */

#include "config.h"

#import "OFUnlockFailedException.h"
#import "OFString.h"

#import "macros.h"

@implementation OFUnlockFailedException
+ (instancetype)exceptionWithClass: (Class)class
			      lock: (id <OFLocking>)lock
{
	return [[[self alloc] initWithClass: class
				       lock: lock] autorelease];
}

- initWithClass: (Class)class
	   lock: (id <OFLocking>)lock
{
	self = [super initWithClass: class];

	_lock = [lock retain];

	return self;
}

- (void)dealloc
{
	[_lock release];

	[super dealloc];
}

- (OFString*)description
{
	return [OFString stringWithFormat:
	    @"A lock of class %@ could not be unlocked in class %@!",
	    [_lock class], _inClass];
}

- (id <OFLocking>)lock
{
	OF_GETTER(_lock, false)
}
@end
